@@ -41,8 +41,8 @@ import re
 
 
 # Globals {{{1
-__version__ = "1.1.0"
-__released__ = "2020-10-11"
+__version__ = "1.3.0"
+__released__ = "2021-01-02"
 __all__ = ['load', 'loads', 'dump', 'dumps', 'NestedTextError']
 
 
@@ -76,7 +76,8 @@ class NestedTextError(Error, ValueError):
 
     prev_line:
 
-        The text of the line immediately before where the problem was found.
+        The text of the meaningful line immediately before where the problem was
+        found.  This would not be a comment or blank line.
 
     template:
 
@@ -272,8 +273,6 @@ class Lines:
             depth = None
             key = None
             value = None
-
-            # all lines except possibly last have a trailing newline, remove it
             line = line.rstrip('\n')
 
             # compute indentation
@@ -458,7 +457,7 @@ def read_all(lines, top, source, on_dup):
     with set_culprit(source):
         lines = Lines(lines)
 
-        if top == 'any':
+        if top in ['any', any]:
             if lines.type_of_next():
                 return read_value(lines, 0, on_dup)
             else:
@@ -466,7 +465,7 @@ def read_all(lines, top, source, on_dup):
 
         next_is = lines.type_of_next()
 
-        if top == 'dict':
+        if top in ['dict', dict]:
             if next_is == "dict item":
                 return read_dict(lines, 0, on_dup)
             elif next_is:
@@ -474,7 +473,7 @@ def read_all(lines, top, source, on_dup):
             else:
                 return {}
 
-        if top == 'list':
+        if top in ['list', list]:
             if next_is == "list item":
                 return read_list(lines, 0, on_dup)
             elif next_is:
@@ -482,7 +481,7 @@ def read_all(lines, top, source, on_dup):
             else:
                 return []
 
-        if top == 'str':
+        if top in ['str', str]:
             if next_is == "string item":
                 return read_string(lines, 0)
             elif next_is:
@@ -508,7 +507,9 @@ def loads(content, top='dict', *, source=None, on_dup=None):
             top-level container and the return value of this function. By
             specifying 'any' you enable support for all three data types, with
             the type of the returned value matching that of top-level container
-            in content.
+            in content. As a short-hand, you may specify the *dict*, *list*,
+            *str*, and *any* built-ins rather than specifying *top* with a
+            string.
         source (str or Path):
             If given, this string is attached to any error messages as the
             culprit. It is otherwise unused. Is often the name of the file that
@@ -534,7 +535,7 @@ def loads(content, top='dict', *, source=None, on_dup=None):
         top argument.  If top is 'any', then the return value will match that of
         top-level data container in the input content. If content is empty, an
         empty data value is return of the type specified by top. If top is
-        'any', None is returned.
+        'any' None is returned.
 
     Raises:
         NestedTextError: if there is a problem in the *NextedText* content.
@@ -564,7 +565,7 @@ def loads(content, top='dict', *, source=None, on_dup=None):
         *loads()* takes an optional argument, *source*. If specified, it is
         added to any error messages. It is often used to designate the source
         of *contents*. For example, if *contents* were read from a file,
-        *culprit* would be the file name.  Here is a typical example of reading
+        *source* would be the file name.  Here is a typical example of reading
         *NestedText* from a file:
 
         .. code-block:: python
@@ -620,7 +621,8 @@ def loads(content, top='dict', *, source=None, on_dup=None):
 
     '''
 
-    return read_all(content.splitlines(True), top, source, on_dup)
+    lines = content.replace('\r\n', '\n').replace('\r', '\n').split('\n')
+    return read_all(lines, top, source, on_dup)
 
 
 # load() {{{2
@@ -642,10 +644,9 @@ def load(f=None, top='dict', *, on_dup=None):
             object is given, it will be read and not closed; utf-8 encoding
             should be used..  If an iterator is given, it should generate full
             lines in the same manner that iterating on a file descriptor would.
-        top:
-            See :func:`loads` description of this argument.
-        on_dup:
-            See :func:`loads` description of this argument.
+
+        kwargs:
+            See :func:`loads` for optional arguments.
 
     Returns:
         The extracted data.
@@ -721,11 +722,10 @@ def render_key(s):
         )
     if (
         len(stripped) < len(s)
-        or s[:1] == "#"
+        or s[:1] in ["#", "'", '"']
         or s.startswith("- ")
         or s.startswith("> ")
         or ': ' in s
-        or s[:1] + s[-1:] in ['""', "''"]
     ):
         if "'" in s:
             quotes = '"', "'"
@@ -783,7 +783,7 @@ def dumps(obj, *, sort_keys=False, indent=4, renderers=None, default=None, level
             functions (functions that take an object and convert it to a string).
             These will be used to convert values to strings during the
             conversion.
-        default (str or func):
+        default (func or 'strict'):
             The default renderer. Use to render otherwise unrecognized objects
             to strings. If not provided an error will be raised for unsupported
             data types. Typical values are *repr* or *str*. If 'strict' is
@@ -982,11 +982,12 @@ def dumps(obj, *, sort_keys=False, indent=4, renderers=None, default=None, level
             for v in obj
         )
     elif is_a_str(obj):
-        if "\n" in obj:
-            content = add_leader(obj, '> ')
+        text = obj.replace('\r\n', '\n').replace('\r', '\n')
+        if "\n" in text or level == 0:
+            content = add_leader(text, '> ')
             need_indented_block = True
         else:
-            content = obj
+            content = text
     elif is_a_scalar(obj):
         if obj is None:
             content = ''
